/*
** 2001-08-18 -	Interface for the error reporting config module.
*/

extern const CfgModule *	cer_describe(MainInfo *min);
